@@ -468,7 +468,6 @@ class SvnCheckout(Task):
             self.logger.debug('repository directory %s exists' % repo)
             return False
 
-
 class VirtualEnv(Task):
     """
     Create a virtualenv environment
@@ -518,9 +517,15 @@ never_create_virtualenv=False):
     def path_resolved(self):
         return self.maker.path(self.path or self.project.name)
 
-    def run(self):
+    def virtualenv_exists(self):
         path = self.path_resolved
         if os.path.exists(path) and os.path.exists(os.path.join(path, 'lib')):
+            return True
+        return False
+
+    def run(self):
+        path = self.path_resolved
+        if self.virtualenv_exists():
             if self.never_create_virtualenv:
                 self.logger.notify('Skipping virtualenv creation as directory %s exists' % path)
                 return
@@ -559,6 +564,9 @@ never_create_virtualenv=False):
         
 
     def iter_subtasks(self):
+        if self.virtualenv_exists() and self.never_create_virtualenv:
+            return []
+
         _tasks = []
         if self.environ.config.has_option('general', 'find_links'):
             find_links = self.environ.config.get('general', 'find_links')
@@ -1178,15 +1186,12 @@ class InstallSpec(Task):
             command(context, arg)
 
     def run_pip(self):
-        ## FIXME: it would save a tiny bit of effort to do the -E
-        ## stuff directly, instead of starting and then replacing the
-        ## subprocess like it'll do with this:
         env = os.environ.copy()
         env['PIP_LOG_EXPLICIT_LEVELS'] = '1'
         env['PIP_DEFAULT_VCS'] = 'svn'
         env['PIP_SKIP_REQUIREMENTS_REGEX'] = '^\w+\s*=[^=]'
         self.maker.run_command(
-            'pip', '-E', self.venv_property('path'),
+            "%s/bin/pip" % self.venv_property('path'),
             'install', '-r', self.spec_filename,
             '-vvvv',
             log_filter=self.log_explicit_filter,
@@ -1439,7 +1444,27 @@ class InstallSpec(Task):
                 hanging_processing[:] = []
             return (line, level)
         return log_filter
-            
+
+class InstallSpecIfPresent(InstallSpec):
+
+    description = """
+    Install the packages from {{task.spec_filename}} if the file exists:
+    {{if maker.exists(task.spec_filename)}}
+    {{for line in open(maker.path(task.spec_filename)):}}
+    {{py: line = line.strip()}}
+    {{if line.startswith('-e') or line.startswith('--editable'):}}* svn checkout {{line.split(None, 1)[1]}}{{else}}* {{line}}{{endif}}{{endfor}}
+    {{else}}
+    The file does not exist, so nothing to do.
+    {{endif}}
+    """
+
+    def run(self):
+        if not self.maker.exists(self.spec_filename):
+            self.logger.notify("Skipping %s because %s does not exist" % (
+                    self.name, self.spec_filename))
+            return
+        InstallSpec.run(self)
+
 class ConditionalTask(Task):
 
     description = """
@@ -1717,3 +1742,29 @@ class Log(Task):
         text = self.interpolate(self.message)
         self.logger.log(self.level, text)
 
+class WGetDirectory(Task):
+
+    repository = interpolated('repository')
+
+    def __init__(self, name, repository, dest, stacklevel=1):
+        super(WGetDirectory, self).__init__(name, stacklevel=stacklevel+1)
+        self.repository = repository
+        self.dest = dest
+
+    def run(self):
+        base = self.repository
+        self.maker.ensure_dir(self.maker.path(self.dest))
+        cmd = ['wget', '--no-check-certificate', '-i', base]
+        self.logger.notify("Running %s" % ' '.join(cmd))
+        self.maker.run_command(cmd,
+                               cwd=self.maker.path(self.dest))
+
+class FetchRequirements(ConditionalTask):
+
+    def __init__(self, name, *args, **kw):
+        conditions = (('{{not asbool(config.requirements_use_wget)}}',
+                       SvnCheckout("%s (using svn checkout)" % name, *args, **kw)),
+                      ('{{asbool(config.requirements_use_wget)}}',
+                       WGetDirectory("%s (using wget -i)" % name, *args, **kw)),
+                      )
+        super(FetchRequirements, self).__init__(name, *conditions)
