@@ -613,9 +613,32 @@ class I18nDude(Project):
                         default='{{os.path.abspath(os.path.join(project.build_properties["virtualenv_path"], ".."))}}/bin/{{project.name}}'),
                 ]
 
+    install_requires = [
+        "zope.interface==3.8.0",
+        "zope.component==3.12.0",
+        "zope.configuration==3.7.4",
+        "zope.event==3.5.1",
+        "zope.proxy==3.6.1",
+        "zope.location==3.9.1",
+        "zope.exceptions==3.6.1",
+        "zope.i18n==3.7.4",
+        "zope.browser==1.3",
+        "zope.contenttype==3.5.5",
+        "zope.i18nmessageid==3.6.1",
+        "zope.publisher==3.13.0",
+        "zope.schema==4.0.1",
+        "zope.security==3.8.3",
+        "zope.tal==3.6.0",
+        "Unidecode==0.04.9",
+        "ordereddict==1.1",
+        "plone.i18n==2.0",
+        "six==1.1.0",
+        "i18ndude==3.2.2",
+        ]
+
     actions = [
         tasks.VirtualEnv(path='opencore/i18ndude'),
-        tasks.EasyInstall('Install i18ndude', 'i18ndude>=3.0'),
+        tasks.EasyInstall('Install i18ndude', *install_requires),
         tasks.EnsureSymlink('symlink i18ndude script',
                             '{{config.binpath}}', '{{config.linkpath}}'),
         tasks.Log('i18ndude usage instructions follow.',
@@ -714,10 +737,10 @@ class OpenCoreProject(OpenCoreBase):
                 default='{{project.req_settings.get("opencore_bundle_name", "opencore-plone25")}}',
                 help='Name of the bundle to use'),
         Setting('opencore_bundle_tar_dir',
-                default='https://svn.openplans.org/eggs/',
+                default='http://dist.socialplanning.org/eggs/',
                 help='Directory/URL where the bundle tarball is kept'),
         Setting('opencore_bundle_svn_repo_dir',
-                default='https://svn.openplans.org/svn/bundles',
+                default='https://svn.socialplanning.org/svn/bundles',
                 help='SVN location of bundles'),
         Setting('opencore_bundle_use_svn',
                 default='false',
@@ -739,6 +762,8 @@ class OpenCoreProject(OpenCoreBase):
                 inherit_config=('general', 'opencore_embed_whitelist'),
                 default='www.youtube.com,video.google.com,www.streetsblog.org,streetsblog.org,p.streetsblog.org,www.streetfilms.org,streetfilms.org,p.streetfilms.org,www.vimeo.com,static.slideshare.net,widget-57.slide.com,www.mindmeister.com,mindmeister.com',
                 help='whitelist of safe sites to embed objects, embed, param, iframe, and layer tags'),
+        Setting("use_pip",
+                default="True"),
         ]
 
     files_dir = os.path.join(os.path.dirname(__file__), 'opencore-files')
@@ -748,8 +773,15 @@ class OpenCoreProject(OpenCoreBase):
     start_script_template = """\
 #!/bin/sh
 cd {{env.base_path}}
-source ./opencore/bin/activate
+. ./opencore/bin/activate
 exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}on{{else}}off{{endif}}
+"""
+
+    test_script_template = """\
+#!/bin/sh
+cd {{env.base_path}}
+. ./opencore/bin/activate
+exec {{config.zope_instance}}/bin/zopectl test -s opencore
 """
 
     flunc_globals_template = """\
@@ -801,6 +833,12 @@ setglobal projprefs    '{{env.config.get("general", "projprefs")}}'
                               (True,
                                GetBundleTarball())),
 
+        tasks.ForEach('Remove Products from opencore bundle',
+                      'product_name',
+                      '{{project.req_settings.get("remove_products")}}',
+                      tasks.Script('rm Product {{task.product_name}}',
+                                   ['rm', '-rf', '{{env.base_path}}/opencore/src/opencore-bundle/{{task.product_name}}'])),
+                                   
         SymlinkProducts('Symlink Products',
                         '{{env.base_path}}/opencore/src/opencore-bundle/*',
                         '{{config.zope_instance}}/Products',
@@ -809,6 +847,8 @@ setglobal projprefs    '{{env.config.get("general", "projprefs")}}'
         InstallZopeFakeEggs('Install fake egg stubs for Zope packages'),
         tasks.InstallSpec('Install OpenCore',
                           '{{config.spec}}'),
+        tasks.EasyInstall('Install GeoPY egg',
+                          "http://dist.socialplanning.org/eggs/geopy-0.93_20071130-py2.4.egg"),
         ## FIXME: linkzope and linkzopebinaries?
         PlaceZopeConfig('Copy Zope etc into build etc'),
         PatchFive(name='Patch Five viewlet security acquisition (see http://trac.openplans.org/openplans/ticket/2026)',
@@ -827,6 +867,10 @@ setglobal projprefs    '{{env.config.get("general", "projprefs")}}'
                          '{{env.base_path}}/bin/start-{{project.name}}',
                          content=start_script_template,
                          svn_add=True, executable=True, overwrite=True),
+        tasks.EnsureFile('Write the test-running script',
+                         '{{env.base_path}}/bin/test-opencore',
+                         content=test_script_template,
+                         svn_add=False, executable=True, overwrite=True),
         tasks.SaveURI(uri='http://{{config.host}}:{{config.port}}/openplans',
                       uri_template='http://{{config.host}}:{{config.port}}/VirtualHostBase/{wsgi.url_scheme}/{HTTP_HOST}/openplans/projects/{project}/VirtualHostRoot{vh_SCRIPT_NAME}',
                       uri_template_main_site='http://{{config.host}}:{{config.port}}/VirtualHostBase/{wsgi.url_scheme}/{HTTP_HOST}/openplans/VirtualHostRoot/projects/{project}',
@@ -1131,7 +1175,7 @@ class ExtraZopeProject(OpenCoreProject):
     start_script_template = """\
 #!/bin/sh
 cd {{env.base_path}}
-source ./opencore/bin/activate
+. ./opencore/bin/activate
 exec {{config.zope_instance}}/bin/runzope -X debug-mode={{if config.debug!='0'}}on{{else}}off{{endif}}
 """
 
